# IoC container for Pip.Services in Python Changelog

## <a name="2.0.0"></a> 2.0.0 (2017-04-05)

### Features
* **refer** Added ReferenceDecorator
* **refer** Added ManagedReferences

## <a name="1.0.0"></a> 1.0.0 (2017-01-28)

Initial public release

### Features
* **build** Container default factory
* **config** Container configuration
* **info** Container information block
* **refer** Container references
* **process** Container system process

### Bug Fixes
No fixes in this version
